==> db4o-5.0-mono.tar.gz: db4o-5.0/src/test/src/com/db4o/test/AllTestsServer.cs <==
/* Copyright (C) 2004 - 2005  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using j4o.lang;
using com.db4o;
namespace com.db4o.test {

    /// <summary>
    /// This class will start a dedicated server for AllTests to run tests
    /// on different machines.
    /// </summary>
    ///
   public class AllTestsServer : AllTests, Runnable {
      
      public AllTestsServer() : base() {
      }
      
      public static void Main(String[] args) {
         new AllTestsServer().run();
      }
      
      public override void run() {
         Db4o.configure().messageLevel(-1);
         logConfiguration();
         Console.WriteLine("Waiting for tests to be run from different machine.");
         Console.WriteLine("\n\nThe server will need to be closed with CTRL + C.\n\n");
         Tester.delete();
         configure();
         Tester.runServer = true;
         Tester.clientServer = true;
         Tester.open();
      }
   }
}

==> db4o-5.5-mono.tar.gz: db4o-5.5/src/test/src/com/db4o/test/AllTestsServer.cs <==
/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using j4o.lang;
using com.db4o;
namespace com.db4o.test {

    /// <summary>
    /// This class will start a dedicated server for AllTests to run tests
    /// on different machines.
    /// </summary>
    ///
   public class AllTestsServer : AllTests, Runnable {
      
      public AllTestsServer() : base() {
      }
      
      public static void Main(String[] args) {
         new AllTestsServer().Run();
      }
      
      public override void Run() {
         Db4o.Configure().MessageLevel(-1);
         LogConfiguration();
         Console.WriteLine("Waiting for tests to be run from different machine.");
         Console.WriteLine("\n\nThe server will need to be closed with CTRL + C.\n\n");
         Tester.Delete();
         Configure();
         Tester.runServer = true;
         Tester.clientServer = true;
         Tester.Open();
      }
   }
}
